@@ -1,22 +1,21 @@
 /*
- * Copyright (c) 1998, 1999, 2000, 2004, 2006
+ * Copyright (c) 1998, 1999, 2000, 2004, 2006, 2010
  *	Tama Communications Corporation
  *
  * This file is part of GNU GLOBAL.
  *
- * GNU GLOBAL is free software; you can redistribute it and/or modify
+ * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
- *
- * GNU GLOBAL is distributed in the hope that it will be useful,
+ * 
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
+ * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef _STRMAKE_H_
@@ -41,5 +40,6 @@
 const char *strmake(const char *, const char *);
 const char *strtrim(const char *, int, int *);
 int strcmp_withterm(const char *, const char *, int);
+const char *strcpy_withterm(char *, const char *, int, int);
 
 #endif /* ! _STRMAKE_H_ */
