@@ -29,9 +29,9 @@
 #include "version.h"
 
 const char *copy = "\
-Copyright (c) 2011 Tama Communications Corporation\n\
+Copyright (c) 2012 Tama Communications Corporation\n\
 License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>\n\
-This is free software: you are free to change and redistribute it.\n\
+This is free software; you are free to change and redistribute it.\n\
 There is NO WARRANTY, to the extent permitted by law.\n\
 This is also commercial (for-profit) software based on BOKIN model.\n\
 Please see the donation page <http://www.gnu.org/software/global/donation.html>.\n\
